import { describe, test, expect, beforeAll } from "vitest";
import guessStudentInfo from "./guessStudentInfo";
import { execSync } from "child_process";
import { join, resolve } from "path";
import { config } from "dotenv";

beforeAll(() => {
  const gitDir = execSync("git rev-parse --show-cdup", { encoding: "utf8" });
  const GIT_DIR_ENV = resolve(join(gitDir?.trim(), ".env"));
  config({ path: GIT_DIR_ENV, debug: false, override: true });
  expect(process.env.TESTS_FOLDER).toContain("se-canonical-auto-tests");
});

describe.concurrent("Guess student info from README", () => {
  test("guessStudentInfo is a function", () => {
    expect(guessStudentInfo).toBeTypeOf("function");
  });

  test("Empty project", () => {
    expect(guessStudentInfo("")).toBeNull();
    expect(guessStudentInfo("323")).toBeNull();
  });

  test("Empty readme", () => {
    // prettier-ignore
    process.env.PROJECT_ROOT = resolve(`${process.env.TESTS_FOLDER}`, "readme/case1");
    expect(process.env.PROJECT_ROOT).toContain("readme/case1");
    expect(guessStudentInfo(process.env.PROJECT_ROOT)).toBeNull();
  });

  test("Good links in readme", () => {
    // prettier-ignore
    process.env.PROJECT_ROOT = resolve(`${process.env.TESTS_FOLDER}`, "readme/case2");
    expect(process.env.PROJECT_ROOT).toContain("readme/case2");
    const result = guessStudentInfo(process.env.PROJECT_ROOT);
    expect(result?.demoUrl).not.toBeUndefined();
    expect(result?.repoUrl).toBeUndefined();
    expect(result?.github).not.toBeUndefined();
  });

  test("Good links in readme 2", () => {
    // prettier-ignore
    process.env.PROJECT_ROOT = resolve(`${process.env.TESTS_FOLDER}`, "readme/case3");
    expect(process.env.PROJECT_ROOT).toContain("readme/case3");
    const result = guessStudentInfo(process.env.PROJECT_ROOT);
    expect(result?.demoUrl).not.toBeUndefined();
    expect(result?.repoUrl).not.toBeUndefined();
    expect(result?.github).not.toBeUndefined();
  });
});
