import { existsSync, readFileSync, readdirSync, statSync } from "fs";
import { join } from "path";

interface InfoI {
  repoUrl?: string;
  demoUrl?: string;
  github?: string;
}
type UserInfoI = InfoI | null;

export default (projectPath: string): UserInfoI => {
  let uInfo: UserInfoI = null;

  try {
    if (existsSync(projectPath) && statSync(projectPath).isDirectory()) {
      const files = readdirSync(projectPath);
      const readme = files.find((f) => /^readme.md$/i.test(f));
      if (readme) {
        const readmePath = join(projectPath, readme);
        const content = readFileSync(readmePath, "utf-8").toString();
        if (content) {
          uInfo = {};
          const matchs = content.match(/http.+github.[a-z]+\/[a-z0-9-_\/]+/gim);

          if (matchs?.length) {
            const repoUrl = matchs.find((i) => i.includes("github.com"));
            if (repoUrl) uInfo.repoUrl = repoUrl;
            const demoUrl = matchs.find((i) => i.includes("github.io"));
            if (demoUrl) uInfo.demoUrl = demoUrl;
          }

          if (uInfo.repoUrl) {
            const repoM = uInfo.repoUrl.match(
              /http.+github.com\/[a-z0-9-_]+/gi
            );
            if (repoM?.[0]) uInfo.github = repoM[0];
          }
          if (uInfo.demoUrl && !uInfo.github) {
            const uMatch2 = uInfo.demoUrl.match(/[a-z0-9-_]+.github.io/gi);
            if (uMatch2?.[0]) {
              const username = uMatch2[0].slice(0, -".github.io".length);
              uInfo.github = `https://github.com/${username}`;
            }
          }
        }
      }
    }
  } catch (error) {}
  return uInfo;
};
